import pytest
import {{ project }}


def test_some_basic_functionality_about():
    assert 2 == 1 + 1


if __name__ == '__main__':
    pytest.main()